# pysensibo
asyncio-friendly python API for Sensibo (https://sensibo.com). Supported on Python 3.11+

Package has been made specifically for [Home Assistant](https://www.home-assistant.io/)

For example usage see test-files
